@@ -2,7 +2,7 @@
 '''AlazarTech Package Registration Script
 
 Usage:
-  register [--dev] [--dry-run] [-p <passfile>] <specfile> <base_url> <version>
+  register [--dev] [--dry-run] [-p <passfile>] <endpoint> <specfile> <base_url> <version>
   register -h | --help
   register --version
 
@@ -16,6 +16,7 @@ Options:
                  sending an HTTP request to the website.
 
 Arguments:
+  <endpoint>      Enpoint where to send request payload.
   <specfile>      Path to the YAML deployment specification file to use for
                   this deployment. See deploy.py for more information about the
                   file's format.
@@ -84,6 +85,13 @@ PRODUCTS = {
     "ATST371": '1044',
     "ATST352": '1045',
     "ATST146": '1046',
+    "ATS9182": '3007',
+    "ATS9628": '1047',
+    "ATS9364": '3004',
+   # "ATS9428": '3008',
+   # "ATS9442": '1048',
+   # "ATS9380": '3005',
+   # "ATS9376": '3006',
 }
 
 # Identifies a package that can be registered to the website
@@ -180,26 +188,26 @@ def payload_from_packages(packages, base_url, version, password):
     return json.dumps(payload)
 
 
-def register(development, passfile, specsfile, baseurl, version, dry_run):
+def register(endpoint, development, passfile, specsfile, baseurl, version, dry_run):
     specs = get_specs_from_file(specsfile)
     files = [thing for spec in specs for thing in get_things(spec)]
     packages = packages_from_files(files)
     if development:
-        endpoint = "https://dev.alazartech.com/go/to/the/dci/password-file-update/"
+        url_endpoint = "https://dev.alazartech.com/go/to/the/dci/" + endpoint + "/"
     else:
-        endpoint = "https://www.alazartech.com/go/to/the/dci/password-file-update/"
+        url_endpoint = "https://www.alazartech.com/go/to/the/dci/" + endpoint + "/"
     password = None
     if passfile:
         with open(passfile, 'r') as passf:
             password = passf.readline().strip()
     payload = payload_from_packages(packages, baseurl, version, password)
     print("The POST request parameters:")
-    print("- endpoint: {}".format(endpoint))
+    print("- endpoint: {}".format(url_endpoint))
     print("- data: {}".format(payload))
     if dry_run:
         print("Dry run, stopping here.")
         return
-    res = requests.post(endpoint,
+    res = requests.post(url_endpoint,
                         params={"key": getenv("WEBSITE_API_KEY")},
                         data=payload)
     if res.status_code != 200:
@@ -210,7 +218,8 @@ def register(development, passfile, specsfile, baseurl, version, dry_run):
 def main():
     '''Main function'''
     arguments = docopt(__doc__, version='Deloy Utility')
-    register(development=arguments['--dev'],
+    register(endpoint=arguments['<endpoint>'],
+             development=arguments['--dev'],
              passfile=arguments['-p'],
              specsfile=arguments['<specfile>'],
              baseurl=arguments['<base_url>'],
